@@ -241,6 +241,12 @@ class AppArgumentParser(argparse.ArgumentParser):
             type=self.int_0_inf,
             help=_('run at most N downloads at the same time'),
         )
+        group.add_argument(
+            '--debug-console-port',
+            metavar='PORT',
+            type=int,
+            help=_('run a web debug console at given port number')
+        )
 
     def _add_log_and_input_args(self):
         group = self.add_argument_group(_('logging and input'))
@@ -1096,13 +1102,6 @@ class AppArgumentParser(argparse.ArgumentParser):
             action='store_true',
             help=_('don’t follow to parent directories on URL path'),
         )
-        group.add_argument(
-            '--no-strong-robots',
-            dest='strong_robots',
-            action='store_false',
-            default=True,
-            help=_('don’t ignore filters for robots.txt'),
-        )
         group.add_argument(
             '--no-strong-redirects',
             dest='strong_redirects',
